from dqc_wrapper.utils.utils_xarray import *
from dqc_wrapper.test_testers.conftest import dirs
import pytest


def test_open_dataset():
   ds = open_dataset(dirs.nc_file, "")
   assert ds.description == "Example dataset"

   ds = open_dataset(dirs.grib_file, "")
   assert ds.time.values


def test_get_variable():
    ds = open_dataset(dirs.nc_file, "")
    response = get_variable(ds, "tas")
    assert response.shape == (5, 320, 160)
    with pytest.raises(Exception):
        get_variable(ds, "fake_var")


def test_get_mask():
    ds = open_dataset(dirs.nc_file, "")
    response = get_mask(ds, "tas")
    assert response.shape == (320, 160)
    with pytest.raises(Exception):
        get_mask(ds, "time")
    with  pytest.raises(KeyError):
        get_mask(ds, "fake_var")


def test_compare_matrix():
    ds = open_dataset(dirs.nc_file, "").load()
    ds['tas'][0, 0, 0] = np.nan # nan first point, values otherwise
    data = ds['tas'][0, :, :]
    mask = np.full((320, 160), True)
    mask[-1, -1] = False # False last point, values otherwise
    mv, uv = compare_matrix(mask, data)
    assert mv == 1 and uv == 1


def test_the_matrix():
    ds = open_dataset(dirs.nc_file, "").load()
    ds['tas'][0, 0, 0] = np.nan # nan first point, values otherwise
    mask2d = ds.isel(time=0)['tas'].copy()
    mask2d[0, 0] = 1
    mask2d[-1, -1] = 0 # False last point, values otherwise
    mv, uv, mask_len = find_missing_unnecessary_values(ds, mask2d, ["time"],
                                                       'tas')
    assert mv == 1 and uv == 5 and mask_len == len(ds.lon) * len(ds.lat)

if __name__ == "__main__":
    test_the_matrix()